from .canary import ElHierro, Fuerteventura, GranCanaria, Gomera, Lanzarote, LaPalma, Tenerife, LanzaroteFuerteventura
from .canaryislands import CanaryIslands
from .core.exceptions import NoDataException, TimestampException
from .response import Response
from .balearic import Mallorca, Menorca
from .balearicislands import BalearicIslands
