from .lanzarote import Lanzarote
from .elhierro import ElHierro
from .fuerteventura import Fuerteventura
from .gomera import Gomera
from .grancanaria import GranCanaria
from .lapalma import LaPalma
from .tenerife import Tenerife
from .lanzafuerte import LanzaroteFuerteventura
